# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class FlightPlanCreationRequestCreationSchema(BaseModel):
    """
    FlightPlanCreationRequestCreationSchema
    """ # noqa: E501
    flight_plan_schema_id: StrictInt
    reference: Annotated[str, Field(strict=True, max_length=120)] = Field(description="The reference that will be given to the generated flight plan")
    future_id: Optional[StrictInt] = None
    meta_launch_now: Optional[StrictBool] = False
    meta_critical_leg_datetime: Optional[datetime] = None
    meta_critical_leg_id: Optional[StrictInt] = None
    meta_landing_datetime: Optional[datetime] = None
    meta_launch_datetime: Optional[datetime] = None
    parent_flight_plan_creation_request_id: Optional[StrictInt] = None
    primary_bot_id: Optional[StrictInt] = None
    primary_bot_schema_id: Optional[StrictInt] = None
    primary_payload_id: Optional[StrictInt] = None
    primary_payload_schema_id: Optional[StrictInt] = None
    resource_assembly_schema_id: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["flight_plan_schema_id", "reference", "future_id", "meta_launch_now", "meta_critical_leg_datetime", "meta_critical_leg_id", "meta_landing_datetime", "meta_launch_datetime", "parent_flight_plan_creation_request_id", "primary_bot_id", "primary_bot_schema_id", "primary_payload_id", "primary_payload_schema_id", "resource_assembly_schema_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlightPlanCreationRequestCreationSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if future_id (nullable) is None
        # and model_fields_set contains the field
        if self.future_id is None and "future_id" in self.model_fields_set:
            _dict['future_id'] = None

        # set to None if meta_critical_leg_datetime (nullable) is None
        # and model_fields_set contains the field
        if self.meta_critical_leg_datetime is None and "meta_critical_leg_datetime" in self.model_fields_set:
            _dict['meta_critical_leg_datetime'] = None

        # set to None if meta_critical_leg_id (nullable) is None
        # and model_fields_set contains the field
        if self.meta_critical_leg_id is None and "meta_critical_leg_id" in self.model_fields_set:
            _dict['meta_critical_leg_id'] = None

        # set to None if meta_landing_datetime (nullable) is None
        # and model_fields_set contains the field
        if self.meta_landing_datetime is None and "meta_landing_datetime" in self.model_fields_set:
            _dict['meta_landing_datetime'] = None

        # set to None if meta_launch_datetime (nullable) is None
        # and model_fields_set contains the field
        if self.meta_launch_datetime is None and "meta_launch_datetime" in self.model_fields_set:
            _dict['meta_launch_datetime'] = None

        # set to None if parent_flight_plan_creation_request_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_flight_plan_creation_request_id is None and "parent_flight_plan_creation_request_id" in self.model_fields_set:
            _dict['parent_flight_plan_creation_request_id'] = None

        # set to None if primary_bot_id (nullable) is None
        # and model_fields_set contains the field
        if self.primary_bot_id is None and "primary_bot_id" in self.model_fields_set:
            _dict['primary_bot_id'] = None

        # set to None if primary_bot_schema_id (nullable) is None
        # and model_fields_set contains the field
        if self.primary_bot_schema_id is None and "primary_bot_schema_id" in self.model_fields_set:
            _dict['primary_bot_schema_id'] = None

        # set to None if primary_payload_id (nullable) is None
        # and model_fields_set contains the field
        if self.primary_payload_id is None and "primary_payload_id" in self.model_fields_set:
            _dict['primary_payload_id'] = None

        # set to None if primary_payload_schema_id (nullable) is None
        # and model_fields_set contains the field
        if self.primary_payload_schema_id is None and "primary_payload_schema_id" in self.model_fields_set:
            _dict['primary_payload_schema_id'] = None

        # set to None if resource_assembly_schema_id (nullable) is None
        # and model_fields_set contains the field
        if self.resource_assembly_schema_id is None and "resource_assembly_schema_id" in self.model_fields_set:
            _dict['resource_assembly_schema_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlightPlanCreationRequestCreationSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "flight_plan_schema_id": obj.get("flight_plan_schema_id"),
            "reference": obj.get("reference"),
            "future_id": obj.get("future_id"),
            "meta_launch_now": obj.get("meta_launch_now") if obj.get("meta_launch_now") is not None else False,
            "meta_critical_leg_datetime": obj.get("meta_critical_leg_datetime"),
            "meta_critical_leg_id": obj.get("meta_critical_leg_id"),
            "meta_landing_datetime": obj.get("meta_landing_datetime"),
            "meta_launch_datetime": obj.get("meta_launch_datetime"),
            "parent_flight_plan_creation_request_id": obj.get("parent_flight_plan_creation_request_id"),
            "primary_bot_id": obj.get("primary_bot_id"),
            "primary_bot_schema_id": obj.get("primary_bot_schema_id"),
            "primary_payload_id": obj.get("primary_payload_id"),
            "primary_payload_schema_id": obj.get("primary_payload_schema_id"),
            "resource_assembly_schema_id": obj.get("resource_assembly_schema_id")
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.resource_assembly_schema_refuel_swaps_api import ResourceAssemblySchemaRefuelSwapsApi


class TestResourceAssemblySchemaRefuelSwapsApi(unittest.TestCase):
    """ResourceAssemblySchemaRefuelSwapsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ResourceAssemblySchemaRefuelSwapsApi()

    def tearDown(self) -> None:
        pass

    def test_get_resource_assembly_schema_refuel_swap(self) -> None:
        """Test case for get_resource_assembly_schema_refuel_swap

        Get Resource Assembly Schema Refuel Swap
        """
        pass

    def test_get_resource_assembly_schema_refuel_swaps(self) -> None:
        """Test case for get_resource_assembly_schema_refuel_swaps

        Get Resource Assembly Schema Refuel Swaps
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.flight_plan_creation_requests_api import FlightPlanCreationRequestsApi


class TestFlightPlanCreationRequestsApi(unittest.TestCase):
    """FlightPlanCreationRequestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlightPlanCreationRequestsApi()

    def tearDown(self) -> None:
        pass

    def test_create_flight_plan_creation_request(self) -> None:
        """Test case for create_flight_plan_creation_request

        Create Flight Plan Creation Request
        """
        pass

    def test_get_flight_plan_creation_request(self) -> None:
        """Test case for get_flight_plan_creation_request

        Get Flight Plan Creation Request
        """
        pass

    def test_get_flight_plan_creation_requests(self) -> None:
        """Test case for get_flight_plan_creation_requests

        Get Flight Plan Creation Requests
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.api.pad_windows_api import PadWindowsApi


class TestPadWindowsApi(unittest.TestCase):
    """PadWindowsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PadWindowsApi()

    def tearDown(self) -> None:
        pass

    def test_get_pad_window(self) -> None:
        """Test case for get_pad_window

        Get Pad Window
        """
        pass

    def test_get_pad_windows(self) -> None:
        """Test case for get_pad_windows

        Get Pad Windows
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_schema_waypoint_creation_schema import FlightPlanSchemaWaypointCreationSchema

class TestFlightPlanSchemaWaypointCreationSchema(unittest.TestCase):
    """FlightPlanSchemaWaypointCreationSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanSchemaWaypointCreationSchema:
        """Test FlightPlanSchemaWaypointCreationSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanSchemaWaypointCreationSchema`
        """
        model = FlightPlanSchemaWaypointCreationSchema()
        if include_optional:
            return FlightPlanSchemaWaypointCreationSchema(
                reference = '',
                port_id = 56,
                coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                    longitude = null, 
                    latitude = null, 
                    altitude = null, 
                    elevation = null, ),
                flight_plan_schema_id = 56
            )
        else:
            return FlightPlanSchemaWaypointCreationSchema(
                flight_plan_schema_id = 56,
        )
        """

    def testFlightPlanSchemaWaypointCreationSchema(self):
        """Test FlightPlanSchemaWaypointCreationSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List
from seres_client.models.available_resource_assembly_schema_component_schema import AvailableResourceAssemblySchemaComponentSchema
from typing import Optional, Set
from typing_extensions import Self

class AvailableResourceAssemblySchemaSchema(BaseModel):
    """
    AvailableResourceAssemblySchemaSchema
    """ # noqa: E501
    port_id: StrictInt
    resource_assembly_schema_id: StrictInt
    requires_transformation: StrictBool
    requires_window: StrictBool
    requires_secondary_window: StrictBool
    components: List[AvailableResourceAssemblySchemaComponentSchema]
    __properties: ClassVar[List[str]] = ["port_id", "resource_assembly_schema_id", "requires_transformation", "requires_window", "requires_secondary_window", "components"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AvailableResourceAssemblySchemaSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in components (list)
        _items = []
        if self.components:
            for _item_components in self.components:
                if _item_components:
                    _items.append(_item_components.to_dict())
            _dict['components'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AvailableResourceAssemblySchemaSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "port_id": obj.get("port_id"),
            "resource_assembly_schema_id": obj.get("resource_assembly_schema_id"),
            "requires_transformation": obj.get("requires_transformation"),
            "requires_window": obj.get("requires_window"),
            "requires_secondary_window": obj.get("requires_secondary_window"),
            "components": [AvailableResourceAssemblySchemaComponentSchema.from_dict(_item) for _item in obj["components"]] if obj.get("components") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.flight_plan_leg_resource_schema import FlightPlanLegResourceSchema

class TestFlightPlanLegResourceSchema(unittest.TestCase):
    """FlightPlanLegResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlightPlanLegResourceSchema:
        """Test FlightPlanLegResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlightPlanLegResourceSchema`
        """
        model = FlightPlanLegResourceSchema()
        if include_optional:
            return FlightPlanLegResourceSchema(
                resource_id = 56,
                resource_assembly_schema_component_id = 56,
                configuration = 'primary',
                resource_schema_action_ids = [
                    56
                    ],
                leg_id = 56,
                id = 56,
                future_id = 56,
                created = '',
                cancelled = True,
                created_by_id = 56
            )
        else:
            return FlightPlanLegResourceSchema(
                resource_id = 56,
                resource_assembly_schema_component_id = 56,
                configuration = 'primary',
                leg_id = 56,
                id = 56,
                future_id = 56,
                created = '',
                cancelled = True,
                created_by_id = 56,
        )
        """

    def testFlightPlanLegResourceSchema(self):
        """Test FlightPlanLegResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.1"

# import apis into sdk package
from seres_client.api.access_keys_api import AccessKeysApi
from seres_client.api.authentication_api import AuthenticationApi
from seres_client.api.available_resource_assemblies_api import AvailableResourceAssembliesApi
from seres_client.api.flight_plan_creation_requests_api import FlightPlanCreationRequestsApi
from seres_client.api.flight_plan_leg_resources_api import FlightPlanLegResourcesApi
from seres_client.api.flight_plan_legs_api import FlightPlanLegsApi
from seres_client.api.flight_plan_references_api import FlightPlanReferencesApi
from seres_client.api.flight_plan_schema_legs_api import FlightPlanSchemaLegsApi
from seres_client.api.flight_plan_schema_waypoints_api import FlightPlanSchemaWaypointsApi
from seres_client.api.flight_plan_schemas_api import FlightPlanSchemasApi
from seres_client.api.flight_plan_waypoints_api import FlightPlanWaypointsApi
from seres_client.api.flight_plans_api import FlightPlansApi
from seres_client.api.future_activities_api import FutureActivitiesApi
from seres_client.api.futures_api import FuturesApi
from seres_client.api.pad_windows_api import PadWindowsApi
from seres_client.api.ports_api import PortsApi
from seres_client.api.resource_assembly_schema_energy_bank_components_api import ResourceAssemblySchemaEnergyBankComponentsApi
from seres_client.api.resource_assembly_schema_energy_bank_consumers_api import ResourceAssemblySchemaEnergyBankConsumersApi
from seres_client.api.resource_assembly_schema_energy_banks_api import ResourceAssemblySchemaEnergyBanksApi
from seres_client.api.resource_assembly_schema_refuel_swaps_api import ResourceAssemblySchemaRefuelSwapsApi
from seres_client.api.resource_assembly_schemas_api import ResourceAssemblySchemasApi
from seres_client.api.resource_schema_action_schemas_api import ResourceSchemaActionSchemasApi
from seres_client.api.resource_schema_actions_api import ResourceSchemaActionsApi
from seres_client.api.resource_schemas_api import ResourceSchemasApi
from seres_client.api.resources_api import ResourcesApi
from seres_client.api.subnets_api import SubnetsApi
from seres_client.api.users_api import UsersApi

# import ApiClient
from seres_client.api_response import ApiResponse
from seres_client.api_client import ApiClient
from seres_client.configuration import Configuration
from seres_client.exceptions import OpenApiException
from seres_client.exceptions import ApiTypeError
from seres_client.exceptions import ApiValueError
from seres_client.exceptions import ApiKeyError
from seres_client.exceptions import ApiAttributeError
from seres_client.exceptions import ApiException

# import models into sdk package
from seres_client.models.access_key_creation_schema import AccessKeyCreationSchema
from seres_client.models.access_key_schema import AccessKeySchema
from seres_client.models.access_key_status_enum import AccessKeyStatusEnum
from seres_client.models.altitude import Altitude
from seres_client.models.app_missions_flightplans_schemas_flight_plan_waypoint_schema_waypoint_coordinate_schema_input import AppMissionsFlightplansSchemasFlightPlanWaypointSchemaWaypointCoordinateSchemaInput
from seres_client.models.app_missions_flightplans_schemas_flight_plan_waypoint_schema_waypoint_coordinate_schema_output import AppMissionsFlightplansSchemasFlightPlanWaypointSchemaWaypointCoordinateSchemaOutput
from seres_client.models.app_missions_schemas_schemas_flight_plan_schema_waypoint_schema_waypoint_coordinate_schema_input import AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaInput
from seres_client.models.app_missions_schemas_schemas_flight_plan_schema_waypoint_schema_waypoint_coordinate_schema_output import AppMissionsSchemasSchemasFlightPlanSchemaWaypointSchemaWaypointCoordinateSchemaOutput
from seres_client.models.available_resource_assembly_schema_component_resource_schema_action_schema import AvailableResourceAssemblySchemaComponentResourceSchemaActionSchema
from seres_client.models.available_resource_assembly_schema_component_schema import AvailableResourceAssemblySchemaComponentSchema
from seres_client.models.available_resource_assembly_schema_schema import AvailableResourceAssemblySchemaSchema
from seres_client.models.average_speed import AverageSpeed
from seres_client.models.configuration_enum import ConfigurationEnum
from seres_client.models.elevation import Elevation
from seres_client.models.expected_status import ExpectedStatus
from seres_client.models.flight_plan_creation_request_creation_schema import FlightPlanCreationRequestCreationSchema
from seres_client.models.flight_plan_creation_request_schema import FlightPlanCreationRequestSchema
from seres_client.models.flight_plan_creation_request_status_enum import FlightPlanCreationRequestStatusEnum
from seres_client.models.flight_plan_creation_schema import FlightPlanCreationSchema
from seres_client.models.flight_plan_leg_creation_schema import FlightPlanLegCreationSchema
from seres_client.models.flight_plan_leg_resource_creation_schema import FlightPlanLegResourceCreationSchema
from seres_client.models.flight_plan_leg_resource_schema import FlightPlanLegResourceSchema
from seres_client.models.flight_plan_leg_schema import FlightPlanLegSchema
from seres_client.models.flight_plan_reference_schema import FlightPlanReferenceSchema
from seres_client.models.flight_plan_schema import FlightPlanSchema
from seres_client.models.flight_plan_schema_creation_schema import FlightPlanSchemaCreationSchema
from seres_client.models.flight_plan_schema_leg_creation_schema import FlightPlanSchemaLegCreationSchema
from seres_client.models.flight_plan_schema_leg_immediate_creation_schema import FlightPlanSchemaLegImmediateCreationSchema
from seres_client.models.flight_plan_schema_leg_schema import FlightPlanSchemaLegSchema
from seres_client.models.flight_plan_schema_leg_update_schema import FlightPlanSchemaLegUpdateSchema
from seres_client.models.flight_plan_schema_revision_creation_schema import FlightPlanSchemaRevisionCreationSchema
from seres_client.models.flight_plan_schema_schema import FlightPlanSchemaSchema
from seres_client.models.flight_plan_schema_type import FlightPlanSchemaType
from seres_client.models.flight_plan_schema_update_schema import FlightPlanSchemaUpdateSchema
from seres_client.models.flight_plan_schema_variation_creation_schema import FlightPlanSchemaVariationCreationSchema
from seres_client.models.flight_plan_schema_waypoint_creation_schema import FlightPlanSchemaWaypointCreationSchema
from seres_client.models.flight_plan_schema_waypoint_immediate_creation_schema import FlightPlanSchemaWaypointImmediateCreationSchema
from seres_client.models.flight_plan_schema_waypoint_schema import FlightPlanSchemaWaypointSchema
from seres_client.models.flight_plan_schema_waypoint_update_schema import FlightPlanSchemaWaypointUpdateSchema
from seres_client.models.flight_plan_type_enum import FlightPlanTypeEnum
from seres_client.models.flight_plan_waypoint_creation_schema import FlightPlanWaypointCreationSchema
from seres_client.models.flight_plan_waypoint_schema import FlightPlanWaypointSchema
from seres_client.models.future_activity_schema import FutureActivitySchema
from seres_client.models.future_activity_type import FutureActivityType
from seres_client.models.future_creation_schema import FutureCreationSchema
from seres_client.models.future_entity_type import FutureEntityType
from seres_client.models.future_schema import FutureSchema
from seres_client.models.http_validation_error import HTTPValidationError
from seres_client.models.implementation_status_enum import ImplementationStatusEnum
from seres_client.models.latitude import Latitude
from seres_client.models.login_response_schema import LoginResponseSchema
from seres_client.models.login_schema import LoginSchema
from seres_client.models.longitude import Longitude
from seres_client.models.new_entity_id_schema import NewEntityIdSchema
from seres_client.models.pad_window_schema import PadWindowSchema
from seres_client.models.paginated_response_schema_access_key_schema import PaginatedResponseSchemaAccessKeySchema
from seres_client.models.paginated_response_schema_flight_plan_creation_request_schema import PaginatedResponseSchemaFlightPlanCreationRequestSchema
from seres_client.models.paginated_response_schema_flight_plan_reference_schema import PaginatedResponseSchemaFlightPlanReferenceSchema
from seres_client.models.paginated_response_schema_flight_plan_schema_schema import PaginatedResponseSchemaFlightPlanSchemaSchema
from seres_client.models.paginated_response_schema_future_activity_schema import PaginatedResponseSchemaFutureActivitySchema
from seres_client.models.paginated_response_schema_resource_assembly_schema_schema import PaginatedResponseSchemaResourceAssemblySchemaSchema
from seres_client.models.paginated_response_schema_resource_schema import PaginatedResponseSchemaResourceSchema
from seres_client.models.paginated_response_schema_resource_schema_schema import PaginatedResponseSchemaResourceSchemaSchema
from seres_client.models.paginated_response_schema_user_schema import PaginatedResponseSchemaUserSchema
from seres_client.models.permission_schema import PermissionSchema
from seres_client.models.port_coordinate import PortCoordinate
from seres_client.models.port_schema import PortSchema
from seres_client.models.resource_assembly_schema_component_schema import ResourceAssemblySchemaComponentSchema
from seres_client.models.resource_assembly_schema_energy_bank_component_schema import ResourceAssemblySchemaEnergyBankComponentSchema
from seres_client.models.resource_assembly_schema_energy_bank_consumer_schema import ResourceAssemblySchemaEnergyBankConsumerSchema
from seres_client.models.resource_assembly_schema_energy_bank_schema import ResourceAssemblySchemaEnergyBankSchema
from seres_client.models.resource_assembly_schema_refuel_swap_schema import ResourceAssemblySchemaRefuelSwapSchema
from seres_client.models.resource_assembly_schema_schema import ResourceAssemblySchemaSchema
from seres_client.models.resource_schema import ResourceSchema
from seres_client.models.resource_schema_action_schema import ResourceSchemaActionSchema
from seres_client.models.resource_schema_action_schema_schema import ResourceSchemaActionSchemaSchema
from seres_client.models.resource_schema_energy_profile_schema import ResourceSchemaEnergyProfileSchema
from seres_client.models.resource_schema_schema import ResourceSchemaSchema
from seres_client.models.resource_type_enum import ResourceTypeEnum
from seres_client.models.subnet_schema import SubnetSchema
from seres_client.models.user_creation_schema import UserCreationSchema
from seres_client.models.user_schema import UserSchema
from seres_client.models.user_status_enum import UserStatusEnum
from seres_client.models.validation_error import ValidationError
from seres_client.models.validation_error_loc_inner import ValidationErrorLocInner



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from seres_client.models.average_speed import AverageSpeed
from typing import Optional, Set
from typing_extensions import Self

class FlightPlanSchemaLegCreationSchema(BaseModel):
    """
    FlightPlanSchemaLegCreationSchema
    """ # noqa: E501
    meta_order: StrictInt
    critical: Optional[StrictBool] = Field(default=False, description="Critical legs are uninterruptable and must be performed exactly at the specified time")
    average_speed: Optional[AverageSpeed] = None
    duration_seconds: Optional[StrictInt] = None
    resource_schema_action_schema_ids: Optional[List[StrictInt]] = None
    origin_waypoint_id: StrictInt
    flight_plan_schema_id: StrictInt
    __properties: ClassVar[List[str]] = ["meta_order", "critical", "average_speed", "duration_seconds", "resource_schema_action_schema_ids", "origin_waypoint_id", "flight_plan_schema_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlightPlanSchemaLegCreationSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of average_speed
        if self.average_speed:
            _dict['average_speed'] = self.average_speed.to_dict()
        # set to None if average_speed (nullable) is None
        # and model_fields_set contains the field
        if self.average_speed is None and "average_speed" in self.model_fields_set:
            _dict['average_speed'] = None

        # set to None if duration_seconds (nullable) is None
        # and model_fields_set contains the field
        if self.duration_seconds is None and "duration_seconds" in self.model_fields_set:
            _dict['duration_seconds'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlightPlanSchemaLegCreationSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "meta_order": obj.get("meta_order"),
            "critical": obj.get("critical") if obj.get("critical") is not None else False,
            "average_speed": AverageSpeed.from_dict(obj["average_speed"]) if obj.get("average_speed") is not None else None,
            "duration_seconds": obj.get("duration_seconds"),
            "resource_schema_action_schema_ids": obj.get("resource_schema_action_schema_ids"),
            "origin_waypoint_id": obj.get("origin_waypoint_id"),
            "flight_plan_schema_id": obj.get("flight_plan_schema_id")
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from seres_client.models.flight_plan_leg_schema import FlightPlanLegSchema
from seres_client.models.flight_plan_type_enum import FlightPlanTypeEnum
from seres_client.models.flight_plan_waypoint_schema import FlightPlanWaypointSchema
from typing import Optional, Set
from typing_extensions import Self

class FlightPlanSchema(BaseModel):
    """
    FlightPlanSchema
    """ # noqa: E501
    reference: Annotated[str, Field(strict=True, max_length=120)]
    flight_plan_schema_id: Optional[StrictInt] = None
    parent_flight_plan_id: Optional[StrictInt] = None
    account_id: StrictInt
    is_private: Optional[StrictBool] = False
    type: Optional[FlightPlanTypeEnum] = None
    id: StrictInt
    future_id: StrictInt
    created_by_id: StrictInt
    created: StrictStr
    cancelled: StrictBool
    origin_port_id: Optional[StrictInt] = None
    destination_port_id: Optional[StrictInt] = None
    offgrid_origin: Optional[StrictBool] = None
    offgrid_destination: Optional[StrictBool] = None
    legs: List[FlightPlanLegSchema]
    waypoints: List[FlightPlanWaypointSchema]
    __properties: ClassVar[List[str]] = ["reference", "flight_plan_schema_id", "parent_flight_plan_id", "account_id", "is_private", "type", "id", "future_id", "created_by_id", "created", "cancelled", "origin_port_id", "destination_port_id", "offgrid_origin", "offgrid_destination", "legs", "waypoints"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlightPlanSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in legs (list)
        _items = []
        if self.legs:
            for _item_legs in self.legs:
                if _item_legs:
                    _items.append(_item_legs.to_dict())
            _dict['legs'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in waypoints (list)
        _items = []
        if self.waypoints:
            for _item_waypoints in self.waypoints:
                if _item_waypoints:
                    _items.append(_item_waypoints.to_dict())
            _dict['waypoints'] = _items
        # set to None if flight_plan_schema_id (nullable) is None
        # and model_fields_set contains the field
        if self.flight_plan_schema_id is None and "flight_plan_schema_id" in self.model_fields_set:
            _dict['flight_plan_schema_id'] = None

        # set to None if parent_flight_plan_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_flight_plan_id is None and "parent_flight_plan_id" in self.model_fields_set:
            _dict['parent_flight_plan_id'] = None

        # set to None if origin_port_id (nullable) is None
        # and model_fields_set contains the field
        if self.origin_port_id is None and "origin_port_id" in self.model_fields_set:
            _dict['origin_port_id'] = None

        # set to None if destination_port_id (nullable) is None
        # and model_fields_set contains the field
        if self.destination_port_id is None and "destination_port_id" in self.model_fields_set:
            _dict['destination_port_id'] = None

        # set to None if offgrid_origin (nullable) is None
        # and model_fields_set contains the field
        if self.offgrid_origin is None and "offgrid_origin" in self.model_fields_set:
            _dict['offgrid_origin'] = None

        # set to None if offgrid_destination (nullable) is None
        # and model_fields_set contains the field
        if self.offgrid_destination is None and "offgrid_destination" in self.model_fields_set:
            _dict['offgrid_destination'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlightPlanSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "reference": obj.get("reference"),
            "flight_plan_schema_id": obj.get("flight_plan_schema_id"),
            "parent_flight_plan_id": obj.get("parent_flight_plan_id"),
            "account_id": obj.get("account_id"),
            "is_private": obj.get("is_private") if obj.get("is_private") is not None else False,
            "type": obj.get("type"),
            "id": obj.get("id"),
            "future_id": obj.get("future_id"),
            "created_by_id": obj.get("created_by_id"),
            "created": obj.get("created"),
            "cancelled": obj.get("cancelled"),
            "origin_port_id": obj.get("origin_port_id"),
            "destination_port_id": obj.get("destination_port_id"),
            "offgrid_origin": obj.get("offgrid_origin"),
            "offgrid_destination": obj.get("offgrid_destination"),
            "legs": [FlightPlanLegSchema.from_dict(_item) for _item in obj["legs"]] if obj.get("legs") is not None else None,
            "waypoints": [FlightPlanWaypointSchema.from_dict(_item) for _item in obj["waypoints"]] if obj.get("waypoints") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.paginated_response_schema_flight_plan_schema_schema import PaginatedResponseSchemaFlightPlanSchemaSchema

class TestPaginatedResponseSchemaFlightPlanSchemaSchema(unittest.TestCase):
    """PaginatedResponseSchemaFlightPlanSchemaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedResponseSchemaFlightPlanSchemaSchema:
        """Test PaginatedResponseSchemaFlightPlanSchemaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedResponseSchemaFlightPlanSchemaSchema`
        """
        model = PaginatedResponseSchemaFlightPlanSchemaSchema()
        if include_optional:
            return PaginatedResponseSchemaFlightPlanSchemaSchema(
                items = [
                    seres_client.models.flight_plan_schema_schema.FlightPlanSchemaSchema(
                        type = 'partial', 
                        flight_plan_type = 'refuel', 
                        reference = '', 
                        waypoints = [
                            seres_client.models.flight_plan_schema_waypoint_schema.FlightPlanSchemaWaypointSchema(
                                reference = '', 
                                port_id = 56, 
                                coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                                    longitude = '', 
                                    latitude = '', 
                                    altitude = '', 
                                    elevation = '', ), 
                                flight_plan_schema_id = 56, 
                                id = 56, 
                                port_name = '', )
                            ], 
                        legs = [
                            seres_client.models.flight_plan_schema_leg_schema.FlightPlanSchemaLegSchema(
                                meta_order = 56, 
                                critical = True, 
                                average_speed = '', 
                                duration_seconds = 56, 
                                resource_schema_action_schema_ids = [
                                    56
                                    ], 
                                origin_waypoint_id = 56, 
                                flight_plan_schema_id = 56, 
                                id = 56, 
                                destination_waypoint_id = 56, 
                                meta_previous_leg_id = 56, 
                                meta_next_leg_id = 56, 
                                is_launch = True, 
                                is_landing = True, )
                            ], 
                        revision_of_id = 56, 
                        variation_of_id = 56, 
                        id = 56, 
                        account_id = 56, 
                        status = 'new', )
                    ],
                has_next = True,
                has_prev = True,
                next_num = 56,
                prev_num = 56,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56
            )
        else:
            return PaginatedResponseSchemaFlightPlanSchemaSchema(
                items = [
                    seres_client.models.flight_plan_schema_schema.FlightPlanSchemaSchema(
                        type = 'partial', 
                        flight_plan_type = 'refuel', 
                        reference = '', 
                        waypoints = [
                            seres_client.models.flight_plan_schema_waypoint_schema.FlightPlanSchemaWaypointSchema(
                                reference = '', 
                                port_id = 56, 
                                coordinate = seres_client.models.waypoint_coordinate_schema.WaypointCoordinateSchema(
                                    longitude = '', 
                                    latitude = '', 
                                    altitude = '', 
                                    elevation = '', ), 
                                flight_plan_schema_id = 56, 
                                id = 56, 
                                port_name = '', )
                            ], 
                        legs = [
                            seres_client.models.flight_plan_schema_leg_schema.FlightPlanSchemaLegSchema(
                                meta_order = 56, 
                                critical = True, 
                                average_speed = '', 
                                duration_seconds = 56, 
                                resource_schema_action_schema_ids = [
                                    56
                                    ], 
                                origin_waypoint_id = 56, 
                                flight_plan_schema_id = 56, 
                                id = 56, 
                                destination_waypoint_id = 56, 
                                meta_previous_leg_id = 56, 
                                meta_next_leg_id = 56, 
                                is_launch = True, 
                                is_landing = True, )
                            ], 
                        revision_of_id = 56, 
                        variation_of_id = 56, 
                        id = 56, 
                        account_id = 56, 
                        status = 'new', )
                    ],
                has_next = True,
                has_prev = True,
                page = 56,
                pages = 56,
                total = 56,
                per_page = 56,
        )
        """

    def testPaginatedResponseSchemaFlightPlanSchemaSchema(self):
        """Test PaginatedResponseSchemaFlightPlanSchemaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import date
from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from seres_client.models.pad_window_schema import PadWindowSchema

from seres_client.api_client import ApiClient, RequestSerialized
from seres_client.api_response import ApiResponse
from seres_client.rest import RESTResponseType


class PadWindowsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_pad_window(
        self,
        window_id: StrictInt,
        future_id: Annotated[Optional[StrictInt], Field(description="Operate in the context of the timeline where this future is the head.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PadWindowSchema:
        """Get Pad Window

        Get the given window

        :param window_id: (required)
        :type window_id: int
        :param future_id: Operate in the context of the timeline where this future is the head.
        :type future_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pad_window_serialize(
            window_id=window_id,
            future_id=future_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PadWindowSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_pad_window_with_http_info(
        self,
        window_id: StrictInt,
        future_id: Annotated[Optional[StrictInt], Field(description="Operate in the context of the timeline where this future is the head.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PadWindowSchema]:
        """Get Pad Window

        Get the given window

        :param window_id: (required)
        :type window_id: int
        :param future_id: Operate in the context of the timeline where this future is the head.
        :type future_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pad_window_serialize(
            window_id=window_id,
            future_id=future_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PadWindowSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_pad_window_without_preload_content(
        self,
        window_id: StrictInt,
        future_id: Annotated[Optional[StrictInt], Field(description="Operate in the context of the timeline where this future is the head.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Pad Window

        Get the given window

        :param window_id: (required)
        :type window_id: int
        :param future_id: Operate in the context of the timeline where this future is the head.
        :type future_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pad_window_serialize(
            window_id=window_id,
            future_id=future_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PadWindowSchema",
            '401': None,
            '404': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_pad_window_serialize(
        self,
        window_id,
        future_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if window_id is not None:
            _path_params['window_id'] = window_id
        # process the query parameters
        # process the header parameters
        if future_id is not None:
            _header_params['future-id'] = future_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader', 
            'APIKeyCookie'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/pad-windows/{window_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_pad_windows(
        self,
        dates: Optional[List[date]] = None,
        pad_id: Optional[StrictInt] = None,
        is_launch_window: Optional[StrictBool] = None,
        is_landing_window: Optional[StrictBool] = None,
        available: Annotated[Optional[StrictBool], Field(description="Exclude windows that are unavailable")] = None,
        compatible_resource_assembly_schema_ids: Annotated[Optional[StrictStr], Field(description="A comma seperated list of ids. Filter the windows with pads that are compatible with all of the given resource assembly schema ids.")] = None,
        future_id: Annotated[Optional[StrictInt], Field(description="Operate in the context of the timeline where this future is the head.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[PadWindowSchema]:
        """Get Pad Windows

        List all windows

        :param dates:
        :type dates: List[date]
        :param pad_id:
        :type pad_id: int
        :param is_launch_window:
        :type is_launch_window: bool
        :param is_landing_window:
        :type is_landing_window: bool
        :param available: Exclude windows that are unavailable
        :type available: bool
        :param compatible_resource_assembly_schema_ids: A comma seperated list of ids. Filter the windows with pads that are compatible with all of the given resource assembly schema ids.
        :type compatible_resource_assembly_schema_ids: str
        :param future_id: Operate in the context of the timeline where this future is the head.
        :type future_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pad_windows_serialize(
            dates=dates,
            pad_id=pad_id,
            is_launch_window=is_launch_window,
            is_landing_window=is_landing_window,
            available=available,
            compatible_resource_assembly_schema_ids=compatible_resource_assembly_schema_ids,
            future_id=future_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PadWindowSchema]",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_pad_windows_with_http_info(
        self,
        dates: Optional[List[date]] = None,
        pad_id: Optional[StrictInt] = None,
        is_launch_window: Optional[StrictBool] = None,
        is_landing_window: Optional[StrictBool] = None,
        available: Annotated[Optional[StrictBool], Field(description="Exclude windows that are unavailable")] = None,
        compatible_resource_assembly_schema_ids: Annotated[Optional[StrictStr], Field(description="A comma seperated list of ids. Filter the windows with pads that are compatible with all of the given resource assembly schema ids.")] = None,
        future_id: Annotated[Optional[StrictInt], Field(description="Operate in the context of the timeline where this future is the head.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[PadWindowSchema]]:
        """Get Pad Windows

        List all windows

        :param dates:
        :type dates: List[date]
        :param pad_id:
        :type pad_id: int
        :param is_launch_window:
        :type is_launch_window: bool
        :param is_landing_window:
        :type is_landing_window: bool
        :param available: Exclude windows that are unavailable
        :type available: bool
        :param compatible_resource_assembly_schema_ids: A comma seperated list of ids. Filter the windows with pads that are compatible with all of the given resource assembly schema ids.
        :type compatible_resource_assembly_schema_ids: str
        :param future_id: Operate in the context of the timeline where this future is the head.
        :type future_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pad_windows_serialize(
            dates=dates,
            pad_id=pad_id,
            is_launch_window=is_launch_window,
            is_landing_window=is_landing_window,
            available=available,
            compatible_resource_assembly_schema_ids=compatible_resource_assembly_schema_ids,
            future_id=future_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PadWindowSchema]",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_pad_windows_without_preload_content(
        self,
        dates: Optional[List[date]] = None,
        pad_id: Optional[StrictInt] = None,
        is_launch_window: Optional[StrictBool] = None,
        is_landing_window: Optional[StrictBool] = None,
        available: Annotated[Optional[StrictBool], Field(description="Exclude windows that are unavailable")] = None,
        compatible_resource_assembly_schema_ids: Annotated[Optional[StrictStr], Field(description="A comma seperated list of ids. Filter the windows with pads that are compatible with all of the given resource assembly schema ids.")] = None,
        future_id: Annotated[Optional[StrictInt], Field(description="Operate in the context of the timeline where this future is the head.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Pad Windows

        List all windows

        :param dates:
        :type dates: List[date]
        :param pad_id:
        :type pad_id: int
        :param is_launch_window:
        :type is_launch_window: bool
        :param is_landing_window:
        :type is_landing_window: bool
        :param available: Exclude windows that are unavailable
        :type available: bool
        :param compatible_resource_assembly_schema_ids: A comma seperated list of ids. Filter the windows with pads that are compatible with all of the given resource assembly schema ids.
        :type compatible_resource_assembly_schema_ids: str
        :param future_id: Operate in the context of the timeline where this future is the head.
        :type future_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_pad_windows_serialize(
            dates=dates,
            pad_id=pad_id,
            is_launch_window=is_launch_window,
            is_landing_window=is_landing_window,
            available=available,
            compatible_resource_assembly_schema_ids=compatible_resource_assembly_schema_ids,
            future_id=future_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PadWindowSchema]",
            '401': None,
            '422': "HTTPValidationError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_pad_windows_serialize(
        self,
        dates,
        pad_id,
        is_launch_window,
        is_landing_window,
        available,
        compatible_resource_assembly_schema_ids,
        future_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'dates': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if dates is not None:
            
            _query_params.append(('dates', dates))
            
        if pad_id is not None:
            
            _query_params.append(('pad_id', pad_id))
            
        if is_launch_window is not None:
            
            _query_params.append(('is_launch_window', is_launch_window))
            
        if is_landing_window is not None:
            
            _query_params.append(('is_landing_window', is_landing_window))
            
        if available is not None:
            
            _query_params.append(('available', available))
            
        if compatible_resource_assembly_schema_ids is not None:
            
            _query_params.append(('compatible_resource_assembly_schema_ids', compatible_resource_assembly_schema_ids))
            
        # process the header parameters
        if future_id is not None:
            _header_params['future-id'] = future_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'APIKeyHeader', 
            'APIKeyCookie'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/pad-windows',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Secore API

    API for the Seres core platform

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seres_client.models.access_key_schema import AccessKeySchema

class TestAccessKeySchema(unittest.TestCase):
    """AccessKeySchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccessKeySchema:
        """Test AccessKeySchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AccessKeySchema`
        """
        model = AccessKeySchema()
        if include_optional:
            return AccessKeySchema(
                name = '',
                description = '',
                permission_ids = [
                    56
                    ],
                id = 56,
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = 'active',
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by_id = 56,
                account_id = 56,
                key = '',
                permissions = [
                    seres_client.models.permission_schema.PermissionSchema(
                        id = 56, 
                        string = '', 
                        referenced = True, )
                    ]
            )
        else:
            return AccessKeySchema(
                name = '',
                description = '',
                permission_ids = [
                    56
                    ],
                id = 56,
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = 'active',
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by_id = 56,
                account_id = 56,
                key = '',
                permissions = [
                    seres_client.models.permission_schema.PermissionSchema(
                        id = 56, 
                        string = '', 
                        referenced = True, )
                    ],
        )
        """

    def testAccessKeySchema(self):
        """Test AccessKeySchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
